detect_algorithm

Function detect_algorithm 

pub fn detect_algorithm(data: &[u8]) -> Option<Algorithm>
Detect the compression algorithm from the magic bytes of data.

Returns None if the data does not match a known format.