MappedFile

Struct MappedFile 

pub struct MappedFile { /* private fields */ }
A read-only memory-mapped file.

Implementations

Source

impl MappedFile

pub fn open(path: impl AsRef<Path>) -> Result<Self>

Open and memory-map a file.

Safety

The caller must ensure that the file is not modified by another process while the mapping is active. This is safe for immutable data files (FASTA, BAM, etc.) which are the primary use case.

pub fn as_bytes(&self) -> &[u8]

The mapped bytes.

pub fn len(&self) -> usize

Length in bytes.

pub fn is_empty(&self) -> bool

Whether the mapped region is empty.